# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._models_py3 import AgentUpdatePatchProperties
from ._models_py3 import AgentUpdateProperties
from ._models_py3 import AppAttachPackage
from ._models_py3 import AppAttachPackageInfoProperties
from ._models_py3 import AppAttachPackageList
from ._models_py3 import AppAttachPackagePatch
from ._models_py3 import AppAttachPackagePatchProperties
from ._models_py3 import AppAttachPackageProperties
from ._models_py3 import Application
from ._models_py3 import ApplicationGroup
from ._models_py3 import ApplicationGroupList
from ._models_py3 import ApplicationGroupPatch
from ._models_py3 import ApplicationList
from ._models_py3 import ApplicationPatch
from ._models_py3 import CloudErrorProperties
from ._models_py3 import Desktop
from ._models_py3 import DesktopList
from ._models_py3 import DesktopPatch
from ._models_py3 import ErrorAdditionalInfo
from ._models_py3 import ErrorDetail
from ._models_py3 import ErrorResponse
from ._models_py3 import ExpandMsixImage
from ._models_py3 import ExpandMsixImageList
from ._models_py3 import HostPool
from ._models_py3 import HostPoolList
from ._models_py3 import HostPoolPatch
from ._models_py3 import Identity
from ._models_py3 import ImportPackageInfoRequest
from ._models_py3 import LogSpecification
from ._models_py3 import MSIXImageURI
from ._models_py3 import MSIXPackage
from ._models_py3 import MSIXPackageList
from ._models_py3 import MSIXPackagePatch
from ._models_py3 import MaintenanceWindowPatchProperties
from ._models_py3 import MaintenanceWindowProperties
from ._models_py3 import MsixPackageApplications
from ._models_py3 import MsixPackageDependencies
from ._models_py3 import OperationProperties
from ._models_py3 import Plan
from ._models_py3 import PrivateEndpoint
from ._models_py3 import PrivateEndpointConnection
from ._models_py3 import PrivateEndpointConnectionListResultWithSystemData
from ._models_py3 import PrivateEndpointConnectionWithSystemData
from ._models_py3 import PrivateLinkResource
from ._models_py3 import PrivateLinkResourceListResult
from ._models_py3 import PrivateLinkServiceConnectionState
from ._models_py3 import ProxyResource
from ._models_py3 import RegistrationInfo
from ._models_py3 import RegistrationInfoPatch
from ._models_py3 import RegistrationTokenList
from ._models_py3 import RegistrationTokenMinimal
from ._models_py3 import Resource
from ._models_py3 import ResourceModelWithAllowedPropertySet
from ._models_py3 import ResourceModelWithAllowedPropertySetIdentity
from ._models_py3 import ResourceModelWithAllowedPropertySetPlan
from ._models_py3 import ResourceModelWithAllowedPropertySetSku
from ._models_py3 import ResourceProviderOperation
from ._models_py3 import ResourceProviderOperationDisplay
from ._models_py3 import ResourceProviderOperationList
from ._models_py3 import ScalingHostPoolReference
from ._models_py3 import ScalingPlan
from ._models_py3 import ScalingPlanList
from ._models_py3 import ScalingPlanPatch
from ._models_py3 import ScalingPlanPersonalSchedule
from ._models_py3 import ScalingPlanPersonalScheduleList
from ._models_py3 import ScalingPlanPersonalSchedulePatch
from ._models_py3 import ScalingPlanPooledSchedule
from ._models_py3 import ScalingPlanPooledScheduleList
from ._models_py3 import ScalingPlanPooledSchedulePatch
from ._models_py3 import ScalingSchedule
from ._models_py3 import SendMessage
from ._models_py3 import ServiceSpecification
from ._models_py3 import SessionHost
from ._models_py3 import SessionHostHealthCheckFailureDetails
from ._models_py3 import SessionHostHealthCheckReport
from ._models_py3 import SessionHostList
from ._models_py3 import SessionHostPatch
from ._models_py3 import Sku
from ._models_py3 import StartMenuItem
from ._models_py3 import StartMenuItemList
from ._models_py3 import SystemData
from ._models_py3 import Time
from ._models_py3 import TrackedResource
from ._models_py3 import UserSession
from ._models_py3 import UserSessionList
from ._models_py3 import Workspace
from ._models_py3 import WorkspaceList
from ._models_py3 import WorkspacePatch

from ._desktop_virtualization_mgmt_client_enums import AppAttachPackageArchitectures
from ._desktop_virtualization_mgmt_client_enums import ApplicationGroupType
from ._desktop_virtualization_mgmt_client_enums import ApplicationType
from ._desktop_virtualization_mgmt_client_enums import CommandLineSetting
from ._desktop_virtualization_mgmt_client_enums import CreatedByType
from ._desktop_virtualization_mgmt_client_enums import DayOfWeek
from ._desktop_virtualization_mgmt_client_enums import FailHealthCheckOnStagingFailure
from ._desktop_virtualization_mgmt_client_enums import HealthCheckName
from ._desktop_virtualization_mgmt_client_enums import HealthCheckResult
from ._desktop_virtualization_mgmt_client_enums import HostPoolType
from ._desktop_virtualization_mgmt_client_enums import HostpoolPublicNetworkAccess
from ._desktop_virtualization_mgmt_client_enums import LoadBalancerType
from ._desktop_virtualization_mgmt_client_enums import PackageTimestamped
from ._desktop_virtualization_mgmt_client_enums import PersonalDesktopAssignmentType
from ._desktop_virtualization_mgmt_client_enums import PreferredAppGroupType
from ._desktop_virtualization_mgmt_client_enums import PrivateEndpointConnectionProvisioningState
from ._desktop_virtualization_mgmt_client_enums import PrivateEndpointServiceConnectionStatus
from ._desktop_virtualization_mgmt_client_enums import ProvisioningState
from ._desktop_virtualization_mgmt_client_enums import PublicNetworkAccess
from ._desktop_virtualization_mgmt_client_enums import RegistrationTokenOperation
from ._desktop_virtualization_mgmt_client_enums import RemoteApplicationType
from ._desktop_virtualization_mgmt_client_enums import SSOSecretType
from ._desktop_virtualization_mgmt_client_enums import ScalingHostPoolType
from ._desktop_virtualization_mgmt_client_enums import ScalingScheduleDaysOfWeekItem
from ._desktop_virtualization_mgmt_client_enums import SessionHandlingOperation
from ._desktop_virtualization_mgmt_client_enums import SessionHostComponentUpdateType
from ._desktop_virtualization_mgmt_client_enums import SessionHostLoadBalancingAlgorithm
from ._desktop_virtualization_mgmt_client_enums import SessionState
from ._desktop_virtualization_mgmt_client_enums import SetStartVMOnConnect
from ._desktop_virtualization_mgmt_client_enums import SkuTier
from ._desktop_virtualization_mgmt_client_enums import StartupBehavior
from ._desktop_virtualization_mgmt_client_enums import Status
from ._desktop_virtualization_mgmt_client_enums import StopHostsWhen
from ._desktop_virtualization_mgmt_client_enums import UpdateState
from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AgentUpdatePatchProperties",
    "AgentUpdateProperties",
    "AppAttachPackage",
    "AppAttachPackageInfoProperties",
    "AppAttachPackageList",
    "AppAttachPackagePatch",
    "AppAttachPackagePatchProperties",
    "AppAttachPackageProperties",
    "Application",
    "ApplicationGroup",
    "ApplicationGroupList",
    "ApplicationGroupPatch",
    "ApplicationList",
    "ApplicationPatch",
    "CloudErrorProperties",
    "Desktop",
    "DesktopList",
    "DesktopPatch",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorResponse",
    "ExpandMsixImage",
    "ExpandMsixImageList",
    "HostPool",
    "HostPoolList",
    "HostPoolPatch",
    "Identity",
    "ImportPackageInfoRequest",
    "LogSpecification",
    "MSIXImageURI",
    "MSIXPackage",
    "MSIXPackageList",
    "MSIXPackagePatch",
    "MaintenanceWindowPatchProperties",
    "MaintenanceWindowProperties",
    "MsixPackageApplications",
    "MsixPackageDependencies",
    "OperationProperties",
    "Plan",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionListResultWithSystemData",
    "PrivateEndpointConnectionWithSystemData",
    "PrivateLinkResource",
    "PrivateLinkResourceListResult",
    "PrivateLinkServiceConnectionState",
    "ProxyResource",
    "RegistrationInfo",
    "RegistrationInfoPatch",
    "RegistrationTokenList",
    "RegistrationTokenMinimal",
    "Resource",
    "ResourceModelWithAllowedPropertySet",
    "ResourceModelWithAllowedPropertySetIdentity",
    "ResourceModelWithAllowedPropertySetPlan",
    "ResourceModelWithAllowedPropertySetSku",
    "ResourceProviderOperation",
    "ResourceProviderOperationDisplay",
    "ResourceProviderOperationList",
    "ScalingHostPoolReference",
    "ScalingPlan",
    "ScalingPlanList",
    "ScalingPlanPatch",
    "ScalingPlanPersonalSchedule",
    "ScalingPlanPersonalScheduleList",
    "ScalingPlanPersonalSchedulePatch",
    "ScalingPlanPooledSchedule",
    "ScalingPlanPooledScheduleList",
    "ScalingPlanPooledSchedulePatch",
    "ScalingSchedule",
    "SendMessage",
    "ServiceSpecification",
    "SessionHost",
    "SessionHostHealthCheckFailureDetails",
    "SessionHostHealthCheckReport",
    "SessionHostList",
    "SessionHostPatch",
    "Sku",
    "StartMenuItem",
    "StartMenuItemList",
    "SystemData",
    "Time",
    "TrackedResource",
    "UserSession",
    "UserSessionList",
    "Workspace",
    "WorkspaceList",
    "WorkspacePatch",
    "AppAttachPackageArchitectures",
    "ApplicationGroupType",
    "ApplicationType",
    "CommandLineSetting",
    "CreatedByType",
    "DayOfWeek",
    "FailHealthCheckOnStagingFailure",
    "HealthCheckName",
    "HealthCheckResult",
    "HostPoolType",
    "HostpoolPublicNetworkAccess",
    "LoadBalancerType",
    "PackageTimestamped",
    "PersonalDesktopAssignmentType",
    "PreferredAppGroupType",
    "PrivateEndpointConnectionProvisioningState",
    "PrivateEndpointServiceConnectionStatus",
    "ProvisioningState",
    "PublicNetworkAccess",
    "RegistrationTokenOperation",
    "RemoteApplicationType",
    "SSOSecretType",
    "ScalingHostPoolType",
    "ScalingScheduleDaysOfWeekItem",
    "SessionHandlingOperation",
    "SessionHostComponentUpdateType",
    "SessionHostLoadBalancingAlgorithm",
    "SessionState",
    "SetStartVMOnConnect",
    "SkuTier",
    "StartupBehavior",
    "Status",
    "StopHostsWhen",
    "UpdateState",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()
